summaryrefslogtreecommitdiff
path: root/src/mono_picture_asset.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/mono_picture_asset.h')
-rw-r--r--src/mono_picture_asset.h7
1 files changed, 4 insertions, 3 deletions
diff --git a/src/mono_picture_asset.h b/src/mono_picture_asset.h
index 7a37fa73..625d6ac8 100644
--- a/src/mono_picture_asset.h
+++ b/src/mono_picture_asset.h
@@ -70,10 +70,11 @@ public:
/** Start a progressive write to a MonoPictureAsset.
* @path file File to write to.
* @path overwrite true to overwrite an existing file; for use when continuing a write which
* previously failed. If in doubt, use false here.
*/
- std::shared_ptr<PictureAssetWriter> start_write (boost::filesystem::path file, bool overwrite) override;
+ std::shared_ptr<PictureAssetWriter> start_write(boost::filesystem::path file, Behaviour behaviour) override;
std::shared_ptr<MonoPictureAssetReader> start_read () const;
bool equals (
@@ -70,10 +70,11 @@ public:
/** Start a progressive write to a MonoPictureAsset.
* @path file File to write to.
- * @path overwrite true to overwrite an existing file; for use when continuing a write which
- * previously failed. If in doubt, use false here.
+ * @path behaviour OVERWRITE_EXISTING to overwrite and potentially add to an existing file
+ * (after a write previously failed), MAKE_NEW to create a new file.
+ * If in doubt, use MAKE_NEW here.
*/